; type to define console messages
; message content and when the message goes away, in millisecs
Type ConsoleMessage
	Field msg$
	Field expires
End Type

; basic constructor for the console message type
; pass it the message and how long you want it to last for
Function CONSOLE_Message.ConsoleMessage(msg$, duration)
	RVAL.ConsoleMessage = New ConsoleMessage
	RVAL\msg = msg
	RVAL\expires = MilliSecs() + duration
	Return RVAL
End Function

; vaguely clean function to handle all console input.
; be sure in the main program to update the same var you send in as a parameter.
; assumes that you have written a CONSOLE_ParseCommand() routine to handle the
; input it collects (see main file for an example)
Function CONSOLE_Do$(CLICommand$)

	RVAL$ = CONSOLE_Input(CLICommand$)
	If Right(RVAL, 1) = Chr$(13)		; if we've got a return on the cli command
		CONSOLE_ParseCommand(Trim(RVAL))
		Return ""
	Else
		Return RVAL
	EndIf

End Function

; simple routine to display all messages.
; this can be made to look much nicer, but tbh I can't be bothered.
Function CONSOLE_Display(CLICommand$)
	For this.ConsoleMessage = Each ConsoleMessage
		If this\expires < MilliSecs()
			Delete this
		Else
			Text 0, y*13, this\msg
			y=y+1
		EndIf
	Next
	Text 0, y*13, "> " + CLICommand$
End Function

; guts of the input routines.  you shouldn't need to call this as
; the CONSOLE_Do() routine handles it.
Function CONSOLE_Input$(CLIcommand$)
	myTempKey = GetKey()
	If myTempKey <> False Then
		If myTempKey = 8 And Len(CLIcommand$) > 0
			CLIcommand$ = Left$(CLIcommand$, Len(CLIcommand$) - 1)
		ElseIf myTempKey = 13
			; do nothing, just don't kill it!
		ElseIf myTempKey < 32 
			myTempKey = 32
		EndIf
		
		If myTempKey <> 8 Then CLIcommand$ = CLIcommand$ + Chr$(myTempKey)
	EndIf
	Return CLIcommand$

End Function

; simple function to parse a space-delimited input string to return the nth parameter.
; pass it the string and the position of the parameter you'd like returned.
Function ParseAttr$(eval$, position)

	If Len(eval) < 1 Then Return "[NULL]"

	eval$ = Lower(eval)
	startpos = 1

	For i = 2 To position
		startPos = Instr(eval, " ", startPos)
		If startPos = 0 Then Return "[NULL]"
		startPos = startPos + 1
	Next

	endPos = Instr(eval, " ", startPos)
	If endPos = 0 Then endPos = Len(eval) + 1

	Return Mid(eval, startPos, endPos - startPos)

End Function